@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,17 +13,19 @@ class QTimer;
 
 namespace TextAutoCorrectionCore
 {
-/**
- * @brief The TextAutoCorrectionSettings class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \brief The TextAutoCorrectionSettings class
+ * \author Laurent Montel <montel@kde.org>
  */
 class TEXTAUTOCORRECTIONCORE_EXPORT TextAutoCorrectionSettings : public TextAutoCorrectionCore::TextAutoCorrectionSettingsBase
 {
     Q_OBJECT
 public:
+    /*!
+     */
     static TextAutoCorrectionSettings *self();
 
-    /** Call this slot instead of directly @ref KConfig::sync() to
+    /*! Call this slot instead of directly \ KConfig::sync() to
       minimize the overall config writes. Calling this slot will
       schedule a sync of the application config file using a timer, so
       that many consecutive calls can be condensed into a single
@@ -38,6 +40,6 @@ private:
     ~TextAutoCorrectionSettings() override;
     static TextAutoCorrectionSettings *mSelf;
 
-    QTimer *mConfigSyncTimer = nullptr;
+    QTimer *const mConfigSyncTimer;
 };
 }
