@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,6 +20,7 @@ void TextAutoGenerateManagerTest::shouldHaveDefaultValues()
     QVERIFY(w.currentChatId().isEmpty());
     QVERIFY(w.textAutoGenerateChatsModel());
     QVERIFY(!w.showArchived());
+    QVERIFY(!w.debug());
 }
 
 void TextAutoGenerateManagerTest::shouldIsFavorite()
@@ -27,4 +28,11 @@ void TextAutoGenerateManagerTest::shouldIsFavorite()
     const TextAutoGenerateText::TextAutoGenerateManager w;
     QVERIFY(!w.chatIsFavorite({}));
 }
+
+void TextAutoGenerateManagerTest::shouldSetDebug()
+{
+    qputenv("TEXTAUTOGENERATE_DEBUGGING", "1");
+    const TextAutoGenerateText::TextAutoGenerateManager w;
+    QVERIFY(w.debug());
+}
 #include "moc_textautogeneratemanagertest.cpp"
