@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -36,7 +36,7 @@ void TextAutoGenerateImportChatBaseJob::start()
         deleteLater();
         return;
     }
-    exportChat();
+    importChat();
 }
 
 QDebug operator<<(QDebug d, const TextAutoGenerateImportChatBaseJob::ImportChatInfo &t)
@@ -48,7 +48,6 @@ QDebug operator<<(QDebug d, const TextAutoGenerateImportChatBaseJob::ImportChatI
 
 bool TextAutoGenerateImportChatBaseJob::ImportChatInfo::isValid() const
 {
-    // TODO add more
     return !filename.isEmpty();
 }
 
