@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,6 +38,12 @@ void TextAutoGenerateSettings::save()
 }
 
 void TextAutoGenerateSettings::load()
+{
+    const KConfigGroup myGroupUi(KSharedConfig::openStateConfig(), u"General"_s);
+    mSystemPrompt = myGroupUi.readEntry("systemPrompt", defaultPrompt());
+}
+
+QString TextAutoGenerateSettings::defaultPrompt()
 {
     const KUser user;
     const QString prompt = i18n(
@@ -45,7 +51,5 @@ void TextAutoGenerateSettings::load()
         "Be helpful, professional, and courteous. Do not give inaccurate "
         "information.",
         user.property(KUser::UserProperty::FullName).toString());
-
-    const KConfigGroup myGroupUi(KSharedConfig::openStateConfig(), u"General"_s);
-    mSystemPrompt = myGroupUi.readEntry("systemPrompt", prompt);
+    return prompt;
 }
