@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,6 +14,7 @@
 #include <KLocalizedString>
 
 #include <QDateTime>
+#include <QJsonObject>
 #include <QUuid>
 
 using namespace TextAutoGenerateText;
@@ -44,7 +45,7 @@ TextAutoGenerateTextPlugin::~TextAutoGenerateTextPlugin() = default;
 
 QByteArray TextAutoGenerateTextPlugin::instanceUuid() const
 {
-    qDebug() << " d->instance " << d->instance;
+    // qDebug() << " d->instance " << d->instance;
     return d->instance->instanceUuid();
 }
 
@@ -99,23 +100,23 @@ QJsonArray TextAutoGenerateTextPlugin::createListMessages(const QList<QJsonObjec
     return array;
 }
 
-void TextAutoGenerateTextPlugin::editMessage(const QByteArray &chatId, const QByteArray &uuid, const QString &str, const QList<QByteArray> &lstTools)
+void TextAutoGenerateTextPlugin::editMessage(const EditSendInfo &editSendInfo)
 {
     if (ready()) {
-        auto messageModel = d->manager->messagesModelFromChatId(chatId);
+        auto messageModel = d->manager->messagesModelFromChatId(editSendInfo.chatId);
         if (messageModel) {
-            const QByteArray llmUuid = messageModel->editMessage(uuid, str);
+            const QByteArray llmUuid = messageModel->editMessage(editSendInfo.messageUuid, editSendInfo.message);
 
             SendToAssistantInfo info;
-            info.message = str;
+            info.message = editSendInfo.message;
             info.messageUuid = llmUuid;
-            info.chatId = chatId;
+            info.chatId = editSendInfo.chatId;
             info.messagesArray = createListMessages(messageModel->convertToOllamaChat());
-            info.tools = lstTools;
+            info.tools = editSendInfo.tools;
 
             initializeProgress(info);
         } else {
-            qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for chatId:" << chatId;
+            qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << "Impossible to find model for chatId:" << editSendInfo.chatId;
         }
     }
 }
@@ -136,21 +137,28 @@ TextAutoGenerateText::TextAutoGenerateTextRequest TextAutoGenerateTextPlugin::co
     return req;
 }
 
-void TextAutoGenerateTextPlugin::sendMessage(const QByteArray &chatId, const QString &str, const QList<QByteArray> &lstTools)
+void TextAutoGenerateTextPlugin::sendMessage(const EditSendInfo &editSendInfo)
 {
     if (ready()) {
-        auto messageModel = d->manager->messagesModelFromChatId(chatId);
+        auto messageModel = d->manager->messagesModelFromChatId(editSendInfo.chatId);
         if (!messageModel) {
-            qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << " Model Message not found" << chatId;
+            qCWarning(TEXTAUTOGENERATETEXT_CORE_LOG) << " Model Message not found" << editSendInfo.chatId;
             return;
         }
         // User Message
         TextAutoGenerateMessage msg;
         msg.setSender(TextAutoGenerateMessage::Sender::User);
-        msg.setContent(str);
+        msg.setContent(editSendInfo.message);
+        TextAutoGenerateAttachments *const atts = TextAutoGenerateAttachmentUtils::createTextAutoGenerateAttachments(
+            TextAutoGenerateAttachmentUtils::generateAttachmentFromAttachmentElementInfos(editSendInfo.attachmentInfoList));
+        msg.setMessageAttachments(*atts);
+        delete atts;
         const auto dt = QDateTime::currentSecsSinceEpoch();
         msg.setDateTime(dt);
         msg.setUuid(QUuid::createUuid().toByteArray(QUuid::Id128));
+        msg.generateHtml();
+
+        qDebug() << " msg*************** " << msg;
 
         // LLM Message
         TextAutoGenerateMessage msgLlm;
@@ -162,23 +170,23 @@ void TextAutoGenerateTextPlugin::sendMessage(const QByteArray &chatId, const QSt
         answerInfo.setEngineName(engineName());
         answerInfo.setModelName(currentModel());
         answerInfo.setInstanceName(d->instance->displayName());
-        answerInfo.setTools(lstTools);
+        answerInfo.setTools(editSendInfo.tools);
         msgLlm.setMessageInfo(answerInfo);
 
         const QByteArray llmUuid = msgLlm.uuid();
         msg.setAnswerUuid(llmUuid);
 
-        d->manager->addMessage(chatId, msg);
+        d->manager->addMessage(editSendInfo.chatId, msg);
         SendToAssistantInfo info;
-        info.message = str;
+        info.message = editSendInfo.message;
         info.messageUuid = llmUuid;
         info.chatId = d->manager->currentChatId();
-        info.tools = lstTools;
+        info.tools = editSendInfo.tools;
 
         info.messagesArray = createListMessages(messageModel->convertToOllamaChat());
-        qDebug() << "info.messagesArray  " << info.messagesArray;
+        // qDebug() << "info.messagesArray  " << info.messagesArray;
 
-        d->manager->addMessage(chatId, msgLlm);
+        d->manager->addMessage(info.chatId, msgLlm);
         // qDebug() << " info " << info;
         initializeProgress(info);
     } else {
@@ -208,6 +216,7 @@ QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateTextPlug
     d.space() << "messageUuid:" << t.messageUuid;
     d.space() << "chatId:" << t.chatId;
     d.space() << "messagesArray:" << t.messagesArray;
+    d.space() << "tools:" << t.tools;
     return d;
 }
 
@@ -218,6 +227,16 @@ QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateTextPlug
     return d;
 }
 
+QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateTextPlugin::EditSendInfo &t)
+{
+    d.space() << "message:" << t.message;
+    d.space() << "messageUuid:" << t.messageUuid;
+    d.space() << "chatId:" << t.chatId;
+    d.space() << "tools:" << t.tools;
+    d.space() << "attachmentList:" << t.attachmentInfoList;
+    return d;
+}
+
 bool TextAutoGenerateTextPlugin::ModelInfoNameAndIdentifier::isValid() const
 {
     return !modelName.isEmpty() && !identifier.isEmpty();
