@@ -1,42 +1,67 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #pragma once
 #include "textautogeneratetext_export.h"
-#include <QDebug>
 #include <QJsonArray>
-#include <TextAutoGenerateText/TextAutoGenerateTextContext>
+class QDebug;
 namespace TextAutoGenerateText
 {
+/*!
+ * \brief The TextAutoGenerateTextRequest class
+ * \author Laurent Montel <montel@kde.org>
+ */
 class TEXTAUTOGENERATETEXT_EXPORT TextAutoGenerateTextRequest
 {
     Q_GADGET
 public:
+    /*!
+     */
     TextAutoGenerateTextRequest();
+    /*!
+     */
     ~TextAutoGenerateTextRequest();
 
+    /*!
+     */
     [[nodiscard]] QString message() const;
+    /*!
+     */
     void setMessage(const QString &newMessage);
 
-    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextContext context() const;
-    void setContext(const TextAutoGenerateText::TextAutoGenerateTextContext &newContext);
-
+    /*!
+     */
     [[nodiscard]] bool operator==(const TextAutoGenerateTextRequest &other) const;
 
+    /*!
+     */
     [[nodiscard]] QString model() const;
+    /*!
+     */
     void setModel(const QString &newModel);
 
+    /*!
+     */
     [[nodiscard]] QJsonArray messages() const;
+    /*!
+     */
     void setMessages(const QJsonArray &newMessages);
 
+    /*!
+     */
+    [[nodiscard]] QList<QByteArray> tools() const;
+    /*!
+     */
+    void setTools(const QList<QByteArray> &newTools);
+
 private:
+    QList<QByteArray> mTools;
     QJsonArray mMessages;
     QString mMessage;
-    TextAutoGenerateText::TextAutoGenerateTextContext mContext;
     QString mModel;
 };
 }
-QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateTextRequest &t);
+TEXTAUTOGENERATETEXT_EXPORT QDebug operator<<(QDebug d, const TextAutoGenerateText::TextAutoGenerateTextRequest &t);
