@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,6 +11,7 @@
 
 class TEXTAUTOGENERATEGENERICNETWORK_EXPORT GenericNetworkServerInfo
 {
+    Q_GADGET
 public:
     enum Limitation : uint8_t {
         None = 0,
@@ -18,8 +19,8 @@ public:
         NoSeed = 2,
         NoSystemMessage = 4,
     };
-    Q_FLAGS(Limitation Limitations)
     Q_DECLARE_FLAGS(Limitations, Limitation)
+    Q_FLAG(Limitations)
 
     GenericNetworkServerInfo();
     ~GenericNetworkServerInfo();
@@ -37,4 +38,6 @@ public:
     [[nodiscard]] QString chatCompletionPath(GenericNetworkManager::PluginNetworkType type) const;
     [[nodiscard]] bool hasVisionSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const;
     [[nodiscard]] bool hasToolsSupport(const QString &currentMode, GenericNetworkManager::PluginNetworkType type) const;
+    [[nodiscard]] bool hasOcrSupport(const QString &currentModel, GenericNetworkManager::PluginNetworkType type) const;
+    [[nodiscard]] bool hasAudioSupport(const QString &currentMode, GenericNetworkManager::PluginNetworkType type) const;
 };
