@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "exampletexttoolplugindialog.h"
 #include "core/tools/textautogeneratetexttoolplugin.h"
 #include "exampletexttoolpluginwidget.h"
-#include <qboxlayout.h>
-#include <qdialogbuttonbox.h>
+#include <QBoxLayout>
+#include <QDialogButtonBox>
 using namespace Qt::Literals::StringLiterals;
 ExampleTextToolPluginDialog::ExampleTextToolPluginDialog(TextAutoGenerateText::TextAutoGenerateTextToolPlugin *plugin, QWidget *parent)
     : QDialog(parent)
