@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "textautogeneratesearchdialogtest.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "widgets/textautogeneratesearchdialog.h"
 #include "widgets/textautogeneratesearchwidget.h"
@@ -15,6 +14,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QVBoxLayout>
 QTEST_MAIN(TextAutoGenerateSearchDialogTest)
 
+using namespace Qt::Literals::StringLiterals;
 TextAutoGenerateSearchDialogTest::TextAutoGenerateSearchDialogTest(QObject *parent)
     : QObject{parent}
 {
@@ -23,7 +23,7 @@ TextAutoGenerateSearchDialogTest::TextAutoGenerateSearchDialogTest(QObject *pare
 
 void TextAutoGenerateSearchDialogTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateSearchDialog d(nullptr);
+    const TextAutoGenerateText::TextAutoGenerateSearchDialog d(nullptr);
     QVERIFY(!d.windowTitle().isEmpty());
     auto mainLayout = d.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
