@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ TextAutoGenerateSearchLineEditTest::TextAutoGenerateSearchLineEditTest(QObject *
 
 void TextAutoGenerateSearchLineEditTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateSearchLineEdit w;
+    const TextAutoGenerateText::TextAutoGenerateSearchLineEdit w;
     // TODO
 }
 
