@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ TextAutoGenerateSearchListViewTest::TextAutoGenerateSearchListViewTest(QObject *
 
 void TextAutoGenerateSearchListViewTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateSearchListView w(nullptr);
+    const TextAutoGenerateText::TextAutoGenerateSearchListView w(nullptr);
     // TODO
 }
 
