@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ TextAutoGenerateSearchWidgetTest::TextAutoGenerateSearchWidgetTest(QObject *pare
 
 void TextAutoGenerateSearchWidgetTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateSearchWidget w(nullptr);
+    const TextAutoGenerateText::TextAutoGenerateSearchWidget w(nullptr);
 
     auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
