@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ TextAutoGenerateTextLineEditAttachmentClickableWidgetTest::TextAutoGenerateTextL
 
 void TextAutoGenerateTextLineEditAttachmentClickableWidgetTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateTextLineEditAttachmentClickableWidget w({});
+    const TextAutoGenerateText::TextAutoGenerateTextLineEditAttachmentClickableWidget w({});
 
     auto mainLayout = w.findChild<QHBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
