@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ TextAutoGenerateTextLineEditAttachmentWidgetTest::TextAutoGenerateTextLineEditAt
 
 void TextAutoGenerateTextLineEditAttachmentWidgetTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateTextLineEditAttachmentWidget w;
+    const TextAutoGenerateText::TextAutoGenerateTextLineEditAttachmentWidget w;
 
     auto mainLayout = w.findChild<TextAutoGenerateText::TextAutoGenerateFlowLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
