@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ TextAutoGenerateTextLineEditTest::TextAutoGenerateTextLineEditTest(QObject *pare
 
 void TextAutoGenerateTextLineEditTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateTextLineEdit d;
+    const TextAutoGenerateText::TextAutoGenerateTextLineEdit d;
     QVERIFY(d.text().isEmpty());
     QVERIFY(!d.placeholderText().isEmpty());
     QVERIFY(!d.acceptRichText());
