@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ TextAutoGenerateToolPluginShowMetaDataDialogTest::TextAutoGenerateToolPluginShow
 
 void TextAutoGenerateToolPluginShowMetaDataDialogTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateToolPluginShowMetaDataDialog w(nullptr);
+    const TextAutoGenerateText::TextAutoGenerateToolPluginShowMetaDataDialog w(nullptr);
     QVERIFY(!w.windowTitle().isEmpty());
 
     auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
