@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ TextAutoGenerateToolPluginShowMetaDataWidgetTest::TextAutoGenerateToolPluginShow
 
 void TextAutoGenerateToolPluginShowMetaDataWidgetTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateToolPluginShowMetaDataWidget w(nullptr);
+    const TextAutoGenerateText::TextAutoGenerateToolPluginShowMetaDataWidget w(nullptr);
     auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
