@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ TextAutoGenerateToolsWidgetTest::TextAutoGenerateToolsWidgetTest(QObject *parent
 
 void TextAutoGenerateToolsWidgetTest::shouldHaveDefaultValues()
 {
-    TextAutoGenerateText::TextAutoGenerateToolsWidget w;
+    const TextAutoGenerateText::TextAutoGenerateToolsWidget w;
     QVERIFY(w.generateListOfActiveTools().isEmpty());
 
     auto mainLayout = w.findChild<TextAutoGenerateText::TextAutoGenerateFlowLayout *>(u"mainLayout"_s);
