@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2025-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,10 +23,12 @@ public:
 
     [[nodiscard]] QString instanceName() const;
 
+    void setInstanceDisplayNames(const QStringList &lst);
 Q_SIGNALS:
     void buttonOkEnabled(bool status);
 
 private:
+    QStringList mInstanceDisplyNames;
     TextAutoGenerateTextInstanceComboBox *const mInstanceComboBox;
     QLineEdit *const mNameLineEdit;
 };
