@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,28 +13,48 @@ class QAction;
 namespace TextEditTextToSpeech
 {
 class TextToSpeechActionsPrivate;
-/**
- * @brief The TextToSpeechActions class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \class TextEditTextToSpeech::TextToSpeechActions
+ * \inmodule TextEditTextToSpeech
+ * \inheaderfile TextEditTextToSpeech/TextToSpeechActions
+ *
+ * \brief The TextToSpeechActions class
+ * \author Laurent Montel <montel@kde.org>
  */
 class TEXTEDITTEXTTOSPEECH_EXPORT TextToSpeechActions : public QObject
 {
     Q_OBJECT
 public:
+    /*!
+     */
     explicit TextToSpeechActions(QObject *parent = nullptr);
+    /*!
+     */
     ~TextToSpeechActions() override;
 
+    /*!
+     */
     [[nodiscard]] QAction *stopAction() const;
 
+    /*!
+     */
     [[nodiscard]] QAction *playPauseAction() const;
 
+    /*!
+     */
     [[nodiscard]] TextToSpeechWidget::State state() const;
 
 public Q_SLOTS:
-    void setState(TextToSpeechWidget::State);
+    /*!
+     */
+    void setState(TextEditTextToSpeech::TextToSpeechWidget::State);
+    /*!
+     */
     void slotStop();
 
 Q_SIGNALS:
+    /*!
+     */
     void stateChanged(TextEditTextToSpeech::TextToSpeechWidget::State state);
 
 private:
