@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,29 +7,50 @@
 #pragma once
 
 #include "textemoticonscore_export.h"
-#include <QDebug>
+#include <QMetaType>
 #include <QString>
+class QDebug;
 namespace TextEmoticonsCore
 {
-/**
- * @brief The CustomEmoji class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \class TextEmoticonsCore::CustomEmoji
+ * \inmodule TextEmoticonsCore
+ * \inheaderfile TextEmoticonsCore/CustomEmoji
+ *
+ * \brief The CustomEmoji class
+ * \author Laurent Montel <montel@kde.org>
  */
 class TEXTEMOTICONSCORE_EXPORT CustomEmoji
 {
     Q_GADGET
 public:
+    /*!
+     */
     CustomEmoji();
 
+    /*!
+     */
     [[nodiscard]] QString identifier() const;
+    /*!
+     */
     void setIdentifier(const QString &newIdentifier);
 
+    /*!
+     */
     [[nodiscard]] QString category() const;
 
+    /*!
+     */
     [[nodiscard]] bool isAnimatedEmoji() const;
+    /*!
+     */
     void setIsAnimatedEmoji(bool newIsAnimatedEmoji);
 
+    /*!
+     */
     [[nodiscard]] QString fileName() const;
+    /*!
+     */
     void setFileName(const QString &newFileName);
 
 private:
@@ -40,4 +61,6 @@ private:
 }
 Q_DECLARE_METATYPE(TextEmoticonsCore::CustomEmoji)
 Q_DECLARE_TYPEINFO(TextEmoticonsCore::CustomEmoji, Q_MOVABLE_TYPE);
+/*!
+ */
 TEXTEMOTICONSCORE_EXPORT QDebug operator<<(QDebug d, const TextEmoticonsCore::CustomEmoji &t);
