@@ -1,37 +1,67 @@
 /*
-   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #pragma once
 #include "textgrammarcheck_export.h"
-#include <QDebug>
+#include <QObject>
 #include <QString>
 #include <QStringList>
-
+class QDebug;
 namespace TextGrammarCheck
 {
+/**
+ * @brief The GrammarAction class
+ * \author Laurent Montel <montel@kde.org>
+ */
 class TEXTGRAMMARCHECK_EXPORT GrammarAction
 {
 public:
+    /*!
+     */
     GrammarAction();
 
+    /*!
+     */
     [[nodiscard]] QString replacement() const;
+    /*!
+     */
     void setReplacement(const QString &replacement);
 
+    /*!
+     */
     [[nodiscard]] int start() const;
+    /*!
+     */
     void setStart(int start);
 
+    /*!
+     */
     [[nodiscard]] int length() const;
+    /*!
+     */
     void setLength(int length);
 
+    /*!
+     */
     [[nodiscard]] QStringList suggestions() const;
+    /*!
+     */
     void setSuggestions(const QStringList &suggestions);
 
+    /*!
+     */
     [[nodiscard]] int blockId() const;
+    /*!
+     */
     void setBlockId(int blockId);
 
+    /*!
+     */
     [[nodiscard]] QStringList infoUrls() const;
+    /*!
+     */
     void setInfoUrls(const QStringList &urls);
 
 private:
@@ -44,4 +74,6 @@ private:
 };
 }
 Q_DECLARE_METATYPE(TextGrammarCheck::GrammarAction)
+/*!
+ */
 TEXTGRAMMARCHECK_EXPORT QDebug operator<<(QDebug d, const TextGrammarCheck::GrammarAction &t);
