@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "grammalectegenerateconfigoptionjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "grammalecte/grammalectegenerateconfigoptionjob.h"
 #include <QStandardPaths>
 #include <QTest>
@@ -31,9 +33,9 @@ void GrammalecteGenerateConfigOptionJobTest::shouldBeAbleToStart()
 {
     TextGrammarCheck::GrammalecteGenerateConfigOptionJob job;
     QVERIFY(!job.canStart());
-    job.setPythonPath(QStringLiteral("ff"));
+    job.setPythonPath(u"ff"_s);
     QVERIFY(!job.canStart());
-    job.setGrammarlecteCliPath(QStringLiteral("ff"));
+    job.setGrammarlecteCliPath(u"ff"_s);
     QVERIFY(job.canStart());
 }
 
