@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,9 @@
 #pragma once
 
 #include "textgrammarcheckprivate_export.h"
-#include <QJsonObject>
 #include <QVector>
 #include <TextGrammarCheck/GrammarError>
+class QJsonObject;
 namespace TextGrammarCheck
 {
 class TEXTGRAMMARCHECK_TESTS_EXPORT GrammalecteParser
