@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -35,8 +35,15 @@ QString TranslatorProxyModel::searchString() const
 void TranslatorProxyModel::setSearchString(const QString &newSearchString)
 {
     if (mSearchString != newSearchString) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        beginFilterChange();
+#endif
         mSearchString = newSearchString;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+        endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
         invalidateFilter();
+#endif
     }
 }
 
